# Generated by Django 3.2.8 on 2022-06-30 23:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0009_trainingrun'),
    ]

    operations = [
        migrations.AddField(
            model_name='trainingrun',
            name='task',
            field=models.CharField(default='', max_length=100),
        ),
    ]
