# Generated by Django 3.2 on 2021-09-10 15:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='policysearchtask',
            old_name='customer_model_metrics',
            new_name='presearch_model_val_metrics',
        ),
    ]
