# Generated by Django 3.2 on 2021-09-17 14:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0003_datasetspec'),
    ]

    operations = [
        migrations.RenameField(
            model_name='datasetspec',
            old_name='payload',
            new_name='image_spec',
        ),
        migrations.AddField(
            model_name='datasetspec',
            name='labels_map',
            field=models.JSONField(default=dict),
        ),
        migrations.AddField(
            model_name='datasetspec',
            name='num_classes',
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name='datasetspec',
            name='split',
            field=models.CharField(default='SPLIT_UNKNOWN', max_length=50),
        ),
        migrations.AddField(
            model_name='datasetspec',
            name='task',
            field=models.CharField(default='COMPUTER_VISION_TASK_UNKNOWN', max_length=250),
        ),
        migrations.AddField(
            model_name='datasetspec',
            name='test_cardinality',
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name='datasetspec',
            name='test_label_distribution',
            field=models.JSONField(default=dict),
        ),
        migrations.AddField(
            model_name='datasetspec',
            name='total_cardinality',
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name='datasetspec',
            name='total_label_distribution',
            field=models.JSONField(default=dict),
        ),
        migrations.AddField(
            model_name='datasetspec',
            name='train_cardinality',
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name='datasetspec',
            name='train_label_distribution',
            field=models.JSONField(default=dict),
        ),
        migrations.AddField(
            model_name='datasetspec',
            name='val_cardinality',
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name='datasetspec',
            name='val_label_distribution',
            field=models.JSONField(default=dict),
        ),
    ]
