# Generated by Django 3.2.8 on 2022-07-08 18:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0010_trainingrun_task'),
    ]

    operations = [
        migrations.AddField(
            model_name='trainingrun',
            name='model_graph_image',
            field=models.CharField(default='', max_length=100),
        ),
    ]
