# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: masterful/proto/layer.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from masterful_gui.backend.proto import action_pb2 as masterful_dot_proto_dot_action__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='masterful/proto/layer.proto',
    package='',
    syntax='proto3',
    serialized_options=None,
    serialized_pb=_b(
        '\n\x1bmasterful/proto/layer.proto\x1a\x1cmasterful/proto/action.proto\"\xb9\x04\n\x05Layer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1e\n\nlayer_type\x18\x02 \x01(\x0e\x32\n.LayerType\x12$\n\x0fordered_actions\x18\x03 \x03(\x0e\x32\x0b.ActionName\x12\x18\n\x10searched_scalars\x18\x04 \x03(\x02\x12\x16\n\x0eoptimal_scalar\x18\x05 \x01(\x02\x12\x13\n\x0btemperature\x18\x06 \x01(\x02\x12\x33\n\x15logits_or_probability\x18\x07 \x01(\x0e\x32\x14.LogitsOrProbability\x12\x16\n\x0enum_magnitudes\x18\x08 \x01(\x05\x12\x15\n\rnum_quantiles\x18\t \x01(\x05\x12\x18\n\x10k_actions_to_run\x18\n \x01(\x05\x12$\n\rsampling_mode\x18\x0b \x01(\x0e\x32\r.SamplingMode\x12\x32\n\x0f\x61\x63tion_mag_grid\x18\x0c \x03(\x0b\x32\x19.Layer.ActionMagGridEntry\x12\x30\n\x0emax_index_grid\x18\r \x03(\x0b\x32\x18.Layer.MaxIndexGridEntry\x1a\x45\n\x12\x41\x63tionMagGridEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Int32ListValue:\x02\x38\x01\x1a\x44\n\x11MaxIndexGridEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Int32ListValue:\x02\x38\x01\" \n\x0eInt32ListValue\x12\x0e\n\x06values\x18\x01 \x03(\x05*\xc9\x01\n\tLayerType\x12\x16\n\x12LAYER_TYPE_UNKNOWN\x10\x00\x12*\n&MASTERFUL_SAMPLE_MAG_BY_QUANTILE_LAYER\x10\x01\x12$\n MASTERFUL_REPLACEMENT_RATE_LAYER\x10\x02\x12\x1d\n\x19MASTERFUL_FIXED_MAG_LAYER\x10\x03\x12\x1f\n\x1bMASTERFUL_TEMPERATURE_LAYER\x10\x04\x12\x12\n\x0eIDENTITY_LAYER\x10\x05*A\n\x0cSamplingMode\x12\x19\n\x15SAMPLING_MODE_UNKNOWN\x10\x00\x12\x0b\n\x07UNIFORM\x10\x01\x12\t\n\x05\x45XACT\x10\x02*U\n\x13LogitsOrProbability\x12!\n\x1dLOGITS_OR_PROBABILITY_UNKNOWN\x10\x00\x12\n\n\x06LOGITS\x10\x01\x12\x0f\n\x0bPROBABILITY\x10\x02\x62\x06proto3'
    ),
    dependencies=[
        masterful_dot_proto_dot_action__pb2.DESCRIPTOR,
    ])

_LAYERTYPE = _descriptor.EnumDescriptor(
    name='LayerType',
    full_name='LayerType',
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(name='LAYER_TYPE_UNKNOWN',
                                        index=0,
                                        number=0,
                                        serialized_options=None,
                                        type=None),
        _descriptor.EnumValueDescriptor(
            name='MASTERFUL_SAMPLE_MAG_BY_QUANTILE_LAYER',
            index=1,
            number=1,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(name='MASTERFUL_REPLACEMENT_RATE_LAYER',
                                        index=2,
                                        number=2,
                                        serialized_options=None,
                                        type=None),
        _descriptor.EnumValueDescriptor(name='MASTERFUL_FIXED_MAG_LAYER',
                                        index=3,
                                        number=3,
                                        serialized_options=None,
                                        type=None),
        _descriptor.EnumValueDescriptor(name='MASTERFUL_TEMPERATURE_LAYER',
                                        index=4,
                                        number=4,
                                        serialized_options=None,
                                        type=None),
        _descriptor.EnumValueDescriptor(name='IDENTITY_LAYER',
                                        index=5,
                                        number=5,
                                        serialized_options=None,
                                        type=None),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=668,
    serialized_end=869,
)
_sym_db.RegisterEnumDescriptor(_LAYERTYPE)

LayerType = enum_type_wrapper.EnumTypeWrapper(_LAYERTYPE)
_SAMPLINGMODE = _descriptor.EnumDescriptor(
    name='SamplingMode',
    full_name='SamplingMode',
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(name='SAMPLING_MODE_UNKNOWN',
                                        index=0,
                                        number=0,
                                        serialized_options=None,
                                        type=None),
        _descriptor.EnumValueDescriptor(name='UNIFORM',
                                        index=1,
                                        number=1,
                                        serialized_options=None,
                                        type=None),
        _descriptor.EnumValueDescriptor(name='EXACT',
                                        index=2,
                                        number=2,
                                        serialized_options=None,
                                        type=None),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=871,
    serialized_end=936,
)
_sym_db.RegisterEnumDescriptor(_SAMPLINGMODE)

SamplingMode = enum_type_wrapper.EnumTypeWrapper(_SAMPLINGMODE)
_LOGITSORPROBABILITY = _descriptor.EnumDescriptor(
    name='LogitsOrProbability',
    full_name='LogitsOrProbability',
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(name='LOGITS_OR_PROBABILITY_UNKNOWN',
                                        index=0,
                                        number=0,
                                        serialized_options=None,
                                        type=None),
        _descriptor.EnumValueDescriptor(name='LOGITS',
                                        index=1,
                                        number=1,
                                        serialized_options=None,
                                        type=None),
        _descriptor.EnumValueDescriptor(name='PROBABILITY',
                                        index=2,
                                        number=2,
                                        serialized_options=None,
                                        type=None),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=938,
    serialized_end=1023,
)
_sym_db.RegisterEnumDescriptor(_LOGITSORPROBABILITY)

LogitsOrProbability = enum_type_wrapper.EnumTypeWrapper(_LOGITSORPROBABILITY)
LAYER_TYPE_UNKNOWN = 0
MASTERFUL_SAMPLE_MAG_BY_QUANTILE_LAYER = 1
MASTERFUL_REPLACEMENT_RATE_LAYER = 2
MASTERFUL_FIXED_MAG_LAYER = 3
MASTERFUL_TEMPERATURE_LAYER = 4
IDENTITY_LAYER = 5
SAMPLING_MODE_UNKNOWN = 0
UNIFORM = 1
EXACT = 2
LOGITS_OR_PROBABILITY_UNKNOWN = 0
LOGITS = 1
PROBABILITY = 2

_LAYER_ACTIONMAGGRIDENTRY = _descriptor.Descriptor(
    name='ActionMagGridEntry',
    full_name='Layer.ActionMagGridEntry',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(name='key',
                                    full_name='Layer.ActionMagGridEntry.key',
                                    index=0,
                                    number=1,
                                    type=5,
                                    cpp_type=1,
                                    label=1,
                                    has_default_value=False,
                                    default_value=0,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='value',
                                    full_name='Layer.ActionMagGridEntry.value',
                                    index=1,
                                    number=2,
                                    type=11,
                                    cpp_type=10,
                                    label=1,
                                    has_default_value=False,
                                    default_value=None,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b('8\001'),
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=492,
    serialized_end=561,
)

_LAYER_MAXINDEXGRIDENTRY = _descriptor.Descriptor(
    name='MaxIndexGridEntry',
    full_name='Layer.MaxIndexGridEntry',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(name='key',
                                    full_name='Layer.MaxIndexGridEntry.key',
                                    index=0,
                                    number=1,
                                    type=5,
                                    cpp_type=1,
                                    label=1,
                                    has_default_value=False,
                                    default_value=0,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='value',
                                    full_name='Layer.MaxIndexGridEntry.value',
                                    index=1,
                                    number=2,
                                    type=11,
                                    cpp_type=10,
                                    label=1,
                                    has_default_value=False,
                                    default_value=None,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b('8\001'),
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=563,
    serialized_end=631,
)

_LAYER = _descriptor.Descriptor(
    name='Layer',
    full_name='Layer',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(name='name',
                                    full_name='Layer.name',
                                    index=0,
                                    number=1,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='layer_type',
                                    full_name='Layer.layer_type',
                                    index=1,
                                    number=2,
                                    type=14,
                                    cpp_type=8,
                                    label=1,
                                    has_default_value=False,
                                    default_value=0,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='ordered_actions',
                                    full_name='Layer.ordered_actions',
                                    index=2,
                                    number=3,
                                    type=14,
                                    cpp_type=8,
                                    label=3,
                                    has_default_value=False,
                                    default_value=[],
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='searched_scalars',
                                    full_name='Layer.searched_scalars',
                                    index=3,
                                    number=4,
                                    type=2,
                                    cpp_type=6,
                                    label=3,
                                    has_default_value=False,
                                    default_value=[],
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='optimal_scalar',
                                    full_name='Layer.optimal_scalar',
                                    index=4,
                                    number=5,
                                    type=2,
                                    cpp_type=6,
                                    label=1,
                                    has_default_value=False,
                                    default_value=float(0),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='temperature',
                                    full_name='Layer.temperature',
                                    index=5,
                                    number=6,
                                    type=2,
                                    cpp_type=6,
                                    label=1,
                                    has_default_value=False,
                                    default_value=float(0),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='logits_or_probability',
                                    full_name='Layer.logits_or_probability',
                                    index=6,
                                    number=7,
                                    type=14,
                                    cpp_type=8,
                                    label=1,
                                    has_default_value=False,
                                    default_value=0,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='num_magnitudes',
                                    full_name='Layer.num_magnitudes',
                                    index=7,
                                    number=8,
                                    type=5,
                                    cpp_type=1,
                                    label=1,
                                    has_default_value=False,
                                    default_value=0,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='num_quantiles',
                                    full_name='Layer.num_quantiles',
                                    index=8,
                                    number=9,
                                    type=5,
                                    cpp_type=1,
                                    label=1,
                                    has_default_value=False,
                                    default_value=0,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='k_actions_to_run',
                                    full_name='Layer.k_actions_to_run',
                                    index=9,
                                    number=10,
                                    type=5,
                                    cpp_type=1,
                                    label=1,
                                    has_default_value=False,
                                    default_value=0,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='sampling_mode',
                                    full_name='Layer.sampling_mode',
                                    index=10,
                                    number=11,
                                    type=14,
                                    cpp_type=8,
                                    label=1,
                                    has_default_value=False,
                                    default_value=0,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='action_mag_grid',
                                    full_name='Layer.action_mag_grid',
                                    index=11,
                                    number=12,
                                    type=11,
                                    cpp_type=10,
                                    label=3,
                                    has_default_value=False,
                                    default_value=[],
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='max_index_grid',
                                    full_name='Layer.max_index_grid',
                                    index=12,
                                    number=13,
                                    type=11,
                                    cpp_type=10,
                                    label=3,
                                    has_default_value=False,
                                    default_value=[],
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[
        _LAYER_ACTIONMAGGRIDENTRY,
        _LAYER_MAXINDEXGRIDENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=62,
    serialized_end=631,
)

_INT32LISTVALUE = _descriptor.Descriptor(
    name='Int32ListValue',
    full_name='Int32ListValue',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(name='values',
                                    full_name='Int32ListValue.values',
                                    index=0,
                                    number=1,
                                    type=5,
                                    cpp_type=1,
                                    label=3,
                                    has_default_value=False,
                                    default_value=[],
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=633,
    serialized_end=665,
)

_LAYER_ACTIONMAGGRIDENTRY.fields_by_name['value'].message_type = _INT32LISTVALUE
_LAYER_ACTIONMAGGRIDENTRY.containing_type = _LAYER
_LAYER_MAXINDEXGRIDENTRY.fields_by_name['value'].message_type = _INT32LISTVALUE
_LAYER_MAXINDEXGRIDENTRY.containing_type = _LAYER
_LAYER.fields_by_name['layer_type'].enum_type = _LAYERTYPE
_LAYER.fields_by_name[
    'ordered_actions'].enum_type = masterful_dot_proto_dot_action__pb2._ACTIONNAME
_LAYER.fields_by_name['logits_or_probability'].enum_type = _LOGITSORPROBABILITY
_LAYER.fields_by_name['sampling_mode'].enum_type = _SAMPLINGMODE
_LAYER.fields_by_name[
    'action_mag_grid'].message_type = _LAYER_ACTIONMAGGRIDENTRY
_LAYER.fields_by_name['max_index_grid'].message_type = _LAYER_MAXINDEXGRIDENTRY
DESCRIPTOR.message_types_by_name['Layer'] = _LAYER
DESCRIPTOR.message_types_by_name['Int32ListValue'] = _INT32LISTVALUE
DESCRIPTOR.enum_types_by_name['LayerType'] = _LAYERTYPE
DESCRIPTOR.enum_types_by_name['SamplingMode'] = _SAMPLINGMODE
DESCRIPTOR.enum_types_by_name['LogitsOrProbability'] = _LOGITSORPROBABILITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Layer = _reflection.GeneratedProtocolMessageType(
    'Layer',
    (_message.Message,),
    {
        'ActionMagGridEntry':
            _reflection.GeneratedProtocolMessageType(
                'ActionMagGridEntry',
                (_message.Message,),
                {
                    'DESCRIPTOR': _LAYER_ACTIONMAGGRIDENTRY,
                    '__module__': 'masterful.proto.layer_pb2'
                    # @@protoc_insertion_point(class_scope:Layer.ActionMagGridEntry)
                }),
        'MaxIndexGridEntry':
            _reflection.GeneratedProtocolMessageType(
                'MaxIndexGridEntry',
                (_message.Message,),
                {
                    'DESCRIPTOR': _LAYER_MAXINDEXGRIDENTRY,
                    '__module__': 'masterful.proto.layer_pb2'
                    # @@protoc_insertion_point(class_scope:Layer.MaxIndexGridEntry)
                }),
        'DESCRIPTOR':
            _LAYER,
        '__module__':
            'masterful.proto.layer_pb2'
        # @@protoc_insertion_point(class_scope:Layer)
    })
_sym_db.RegisterMessage(Layer)
_sym_db.RegisterMessage(Layer.ActionMagGridEntry)
_sym_db.RegisterMessage(Layer.MaxIndexGridEntry)

Int32ListValue = _reflection.GeneratedProtocolMessageType(
    'Int32ListValue',
    (_message.Message,),
    {
        'DESCRIPTOR': _INT32LISTVALUE,
        '__module__': 'masterful.proto.layer_pb2'
        # @@protoc_insertion_point(class_scope:Int32ListValue)
    })
_sym_db.RegisterMessage(Int32ListValue)

_LAYER_ACTIONMAGGRIDENTRY._options = None
_LAYER_MAXINDEXGRIDENTRY._options = None
# @@protoc_insertion_point(module_scope)
