# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: masterful/proto/params.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='masterful/proto/params.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1cmasterful/proto/params.proto\"\x9b\x03\n\x12\x41rchitectureParams\x12\x0c\n\x04task\x18\x01 \x01(\t\x12\x13\n\x0bnum_classes\x18\x02 \x01(\x05\x12\x1b\n\x13\x65nsemble_multiplier\x18\x03 \x01(\x05\x12\x15\n\rbackbone_only\x18\x04 \x01(\x08\x12 \n\x0binput_shape\x18\x05 \x01(\x0b\x32\x0b.InputShape\x12\x13\n\x0binput_range\x18\x06 \x01(\t\x12\x13\n\x0binput_dtype\x18\x07 \x01(\t\x12\x1b\n\x13input_channels_last\x18\x08 \x01(\x08\x12\x19\n\x11prediction_logits\x18\t \x01(\x08\x12\x18\n\x10prediction_dtype\x18\n \x01(\t\x12\x1c\n\x14prediction_structure\x18\x0b \x01(\t\x12\x18\n\x10prediction_shape\x18\x0c \x01(\t\x12\x18\n\x10total_parameters\x18\r \x01(\x03\x12\x1c\n\x14trainable_parameters\x18\x0e \x01(\x03\x12 \n\x18non_trainable_parameters\x18\x0f \x01(\x03\"=\n\nInputShape\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\x12\x10\n\x08\x63hannels\x18\x03 \x01(\x05\"\xcb\x02\n\x12OptimizationParams\x12\x12\n\nbatch_size\x18\x01 \x01(\x05\x12\x16\n\x0e\x64rop_remainder\x18\x02 \x01(\x08\x12\x0e\n\x06\x65pochs\x18\x03 \x01(\x05\x12\x15\n\rlearning_rate\x18\x04 \x01(\t\x12\x1e\n\x16learning_rate_schedule\x18\x05 \x01(\t\x12\x1e\n\x16learning_rate_callback\x18\x06 \x01(\t\x12\x1c\n\x14warmup_learning_rate\x18\x07 \x01(\t\x12\x15\n\rwarmup_epochs\x18\x08 \x01(\x05\x12\x11\n\toptimizer\x18\t \x01(\t\x12\x0c\n\x04loss\x18\n \x03(\t\x12\x1f\n\x17\x65\x61rly_stopping_callback\x18\x0b \x01(\t\x12\x0f\n\x07metrics\x18\x0c \x03(\t\x12\x1a\n\x12readonly_callbacks\x18\r \x03(\t\"\x1f\n\tSslParams\x12\x12\n\nalgorithms\x18\x01 \x03(\t\"\x8a\x02\n\nDataParams\x12\x13\n\x0bnum_classes\x18\x01 \x01(\x05\x12\x0f\n\x07\x63v_task\x18\x02 \x01(\t\x12\x13\n\x0bimage_shape\x18\x03 \x01(\t\x12\x13\n\x0bimage_range\x18\x04 \x01(\t\x12\x13\n\x0bimage_dtype\x18\x05 \x01(\t\x12\x1b\n\x13image_channels_last\x18\x06 \x01(\x08\x12\x13\n\x0blabel_dtype\x18\x07 \x01(\t\x12\x13\n\x0blabel_shape\x18\x08 \x01(\t\x12\x17\n\x0flabel_structure\x18\t \x01(\t\x12\x14\n\x0clabel_sparse\x18\n \x01(\x08\x12!\n\x19label_bounding_box_format\x18\x0b \x01(\tb\x06proto3')
)




_ARCHITECTUREPARAMS = _descriptor.Descriptor(
  name='ArchitectureParams',
  full_name='ArchitectureParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task', full_name='ArchitectureParams.task', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_classes', full_name='ArchitectureParams.num_classes', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ensemble_multiplier', full_name='ArchitectureParams.ensemble_multiplier', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='backbone_only', full_name='ArchitectureParams.backbone_only', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_shape', full_name='ArchitectureParams.input_shape', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_range', full_name='ArchitectureParams.input_range', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_dtype', full_name='ArchitectureParams.input_dtype', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_channels_last', full_name='ArchitectureParams.input_channels_last', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prediction_logits', full_name='ArchitectureParams.prediction_logits', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prediction_dtype', full_name='ArchitectureParams.prediction_dtype', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prediction_structure', full_name='ArchitectureParams.prediction_structure', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prediction_shape', full_name='ArchitectureParams.prediction_shape', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_parameters', full_name='ArchitectureParams.total_parameters', index=12,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trainable_parameters', full_name='ArchitectureParams.trainable_parameters', index=13,
      number=14, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='non_trainable_parameters', full_name='ArchitectureParams.non_trainable_parameters', index=14,
      number=15, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=444,
)


_INPUTSHAPE = _descriptor.Descriptor(
  name='InputShape',
  full_name='InputShape',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='width', full_name='InputShape.width', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='height', full_name='InputShape.height', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channels', full_name='InputShape.channels', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=446,
  serialized_end=507,
)


_OPTIMIZATIONPARAMS = _descriptor.Descriptor(
  name='OptimizationParams',
  full_name='OptimizationParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='batch_size', full_name='OptimizationParams.batch_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drop_remainder', full_name='OptimizationParams.drop_remainder', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='epochs', full_name='OptimizationParams.epochs', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='learning_rate', full_name='OptimizationParams.learning_rate', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='learning_rate_schedule', full_name='OptimizationParams.learning_rate_schedule', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='learning_rate_callback', full_name='OptimizationParams.learning_rate_callback', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='warmup_learning_rate', full_name='OptimizationParams.warmup_learning_rate', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='warmup_epochs', full_name='OptimizationParams.warmup_epochs', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optimizer', full_name='OptimizationParams.optimizer', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='loss', full_name='OptimizationParams.loss', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='early_stopping_callback', full_name='OptimizationParams.early_stopping_callback', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='OptimizationParams.metrics', index=11,
      number=12, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='readonly_callbacks', full_name='OptimizationParams.readonly_callbacks', index=12,
      number=13, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=510,
  serialized_end=841,
)


_SSLPARAMS = _descriptor.Descriptor(
  name='SslParams',
  full_name='SslParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='algorithms', full_name='SslParams.algorithms', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=843,
  serialized_end=874,
)


_DATAPARAMS = _descriptor.Descriptor(
  name='DataParams',
  full_name='DataParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_classes', full_name='DataParams.num_classes', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cv_task', full_name='DataParams.cv_task', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_shape', full_name='DataParams.image_shape', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_range', full_name='DataParams.image_range', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_dtype', full_name='DataParams.image_dtype', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_channels_last', full_name='DataParams.image_channels_last', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_dtype', full_name='DataParams.label_dtype', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_shape', full_name='DataParams.label_shape', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_structure', full_name='DataParams.label_structure', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_sparse', full_name='DataParams.label_sparse', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_bounding_box_format', full_name='DataParams.label_bounding_box_format', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=877,
  serialized_end=1143,
)

_ARCHITECTUREPARAMS.fields_by_name['input_shape'].message_type = _INPUTSHAPE
DESCRIPTOR.message_types_by_name['ArchitectureParams'] = _ARCHITECTUREPARAMS
DESCRIPTOR.message_types_by_name['InputShape'] = _INPUTSHAPE
DESCRIPTOR.message_types_by_name['OptimizationParams'] = _OPTIMIZATIONPARAMS
DESCRIPTOR.message_types_by_name['SslParams'] = _SSLPARAMS
DESCRIPTOR.message_types_by_name['DataParams'] = _DATAPARAMS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ArchitectureParams = _reflection.GeneratedProtocolMessageType('ArchitectureParams', (_message.Message,), {
  'DESCRIPTOR' : _ARCHITECTUREPARAMS,
  '__module__' : 'masterful.proto.params_pb2'
  # @@protoc_insertion_point(class_scope:ArchitectureParams)
  })
_sym_db.RegisterMessage(ArchitectureParams)

InputShape = _reflection.GeneratedProtocolMessageType('InputShape', (_message.Message,), {
  'DESCRIPTOR' : _INPUTSHAPE,
  '__module__' : 'masterful.proto.params_pb2'
  # @@protoc_insertion_point(class_scope:InputShape)
  })
_sym_db.RegisterMessage(InputShape)

OptimizationParams = _reflection.GeneratedProtocolMessageType('OptimizationParams', (_message.Message,), {
  'DESCRIPTOR' : _OPTIMIZATIONPARAMS,
  '__module__' : 'masterful.proto.params_pb2'
  # @@protoc_insertion_point(class_scope:OptimizationParams)
  })
_sym_db.RegisterMessage(OptimizationParams)

SslParams = _reflection.GeneratedProtocolMessageType('SslParams', (_message.Message,), {
  'DESCRIPTOR' : _SSLPARAMS,
  '__module__' : 'masterful.proto.params_pb2'
  # @@protoc_insertion_point(class_scope:SslParams)
  })
_sym_db.RegisterMessage(SslParams)

DataParams = _reflection.GeneratedProtocolMessageType('DataParams', (_message.Message,), {
  'DESCRIPTOR' : _DATAPARAMS,
  '__module__' : 'masterful.proto.params_pb2'
  # @@protoc_insertion_point(class_scope:DataParams)
  })
_sym_db.RegisterMessage(DataParams)


# @@protoc_insertion_point(module_scope)
