# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: masterful/proto/policy.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from masterful_gui.backend.proto import layer_pb2 as masterful_dot_proto_dot_layer__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='masterful/proto/policy.proto',
    package='',
    syntax='proto3',
    serialized_options=None,
    serialized_pb=_b(
        '\n\x1cmasterful/proto/policy.proto\x1a\x1bmasterful/proto/layer.proto\"B\n\x06Policy\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\npolicy_key\x18\x02 \x01(\t\x12\x16\n\x06layers\x18\x03 \x03(\x0b\x32\x06.Layerb\x06proto3'
    ),
    dependencies=[
        masterful_dot_proto_dot_layer__pb2.DESCRIPTOR,
    ])

_POLICY = _descriptor.Descriptor(
    name='Policy',
    full_name='Policy',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(name='name',
                                    full_name='Policy.name',
                                    index=0,
                                    number=1,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='policy_key',
                                    full_name='Policy.policy_key',
                                    index=1,
                                    number=2,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='layers',
                                    full_name='Policy.layers',
                                    index=2,
                                    number=3,
                                    type=11,
                                    cpp_type=10,
                                    label=3,
                                    has_default_value=False,
                                    default_value=[],
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=61,
    serialized_end=127,
)

_POLICY.fields_by_name[
    'layers'].message_type = masterful_dot_proto_dot_layer__pb2._LAYER
DESCRIPTOR.message_types_by_name['Policy'] = _POLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Policy = _reflection.GeneratedProtocolMessageType(
    'Policy',
    (_message.Message,),
    {
        'DESCRIPTOR': _POLICY,
        '__module__': 'masterful.proto.policy_pb2'
        # @@protoc_insertion_point(class_scope:Policy)
    })
_sym_db.RegisterMessage(Policy)

# @@protoc_insertion_point(module_scope)
