# Generated by Django 3.2.8 on 2022-08-11 16:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0012_auto_20220727_1451'),
    ]

    operations = [
        migrations.AddField(
            model_name='trainingrun',
            name='datasets',
            field=models.JSONField(default=dict),
        ),
    ]
