# Generated by Django 3.2.8 on 2022-02-14 22:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0005_policysearchtask_engine_version'),
    ]

    operations = [
        migrations.AddField(
            model_name='policysearchtask',
            name='fit_was_captured',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='policysearchtask',
            name='learned_policy_val_metrics',
            field=models.JSONField(default=dict),
        ),
    ]
