# Generated by Django 3.2 on 2021-09-17 13:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0002_rename_customer_model_metrics_policysearchtask_presearch_model_val_metrics'),
    ]

    operations = [
        migrations.CreateModel(
            name='DatasetSpec',
            fields=[
                ('title', models.CharField(max_length=250, primary_key=True, serialize=False)),
                ('payload', models.JSONField(default=dict)),
            ],
        ),
    ]
