# Generated by Django 3.2.8 on 2022-06-30 22:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0008_auto_20220427_1456'),
    ]

    operations = [
        migrations.CreateModel(
            name='TrainingRun',
            fields=[
                ('name', models.CharField(max_length=250, primary_key=True, serialize=False)),
                ('completed_ts', models.DateTimeField()),
                ('model_info', models.JSONField(default=dict)),
                ('policy_search_results', models.JSONField(default=dict)),
                ('approach_name', models.CharField(max_length=120)),
                ('masterful_version', models.CharField(default='', max_length=100)),
            ],
        ),
    ]
