# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: masterful/proto/search_task.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from masterful_gui.backend.proto import layer_pb2 as masterful_dot_proto_dot_layer__pb2
from masterful_gui.backend.proto import metrics_pb2 as masterful_dot_proto_dot_metrics__pb2
from masterful_gui.backend.proto import metadata_pb2 as masterful_dot_proto_dot_metadata__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='masterful/proto/search_task.proto',
    package='',
    syntax='proto3',
    serialized_options=None,
    serialized_pb=_b(
        '\n!masterful/proto/search_task.proto\x1a\x1bmasterful/proto/layer.proto\x1a\x1dmasterful/proto/metrics.proto\x1a\x1emasterful/proto/metadata.proto\"\xa1\x02\n\x10PolicySearchTask\x12\x13\n\x0bpolicy_name\x18\x01 \x01(\t\x12\x15\n\rapproach_name\x18\x02 \x01(\t\x12*\n\x11node_search_tasks\x18\x03 \x03(\x0b\x32\x0f.NodeSearchTask\x12-\n\x1bpresearch_model_val_metrics\x18\x04 \x01(\x0b\x32\x08.Metrics\x12\x16\n\x0e\x65ngine_version\x18\x05 \x01(\t\x12\x18\n\x10\x66it_was_captured\x18\x06 \x01(\x08\x12,\n\x1alearned_policy_val_metrics\x18\x07 \x01(\x0b\x32\x08.Metrics\x12&\n\ttask_type\x18\x08 \x01(\x0e\x32\x13.ComputerVisionTask\"\xc7\x03\n\x0eNodeSearchTask\x12\x1d\n\x04type\x18\x01 \x01(\x0e\x32\x0f.NodeSearchType\x12\r\n\x05title\x18\x02 \x01(\t\x12\x18\n\x10searched_scalars\x18\x03 \x03(\x02\x12\x16\n\x0eoptimal_scalar\x18\x04 \x01(\x02\x12\'\n\x0bval_metrics\x18\x05 \x03(\x0b\x32\x12.NodeSearchMetrics\x12\x1f\n\x0fsearched_layers\x18\x06 \x03(\x0b\x32\x06.Layer\x12=\n\x10node_scalars_map\x18\x07 \x03(\x0b\x32#.NodeSearchTask.NodeScalarsMapEntry\x12J\n\x17node_optimal_scalar_map\x18\x08 \x03(\x0b\x32).NodeSearchTask.NodeOptimalScalarMapEntry\x1a\x43\n\x13NodeScalarsMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x0c.ScalarsList:\x02\x38\x01\x1a;\n\x19NodeOptimalScalarMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\xbd\x01\n\x11NodeSearchMetrics\x12\x17\n\x0fsearched_scalar\x18\x01 \x01(\x02\x12\x19\n\x07metrics\x18\x02 \x01(\x0b\x32\x08.Metrics\x12>\n\x0fnode_scalar_map\x18\x03 \x03(\x0b\x32%.NodeSearchMetrics.NodeScalarMapEntry\x1a\x34\n\x12NodeScalarMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\x1e\n\x0bScalarsList\x12\x0f\n\x07scalars\x18\x01 \x03(\x02*n\n\x0eNodeSearchType\x12\x1c\n\x18NODE_SEARCH_TYPE_UNKNOWN\x10\x00\x12\t\n\x05LAYER\x10\x01\x12\x1b\n\x17SYNTHETIC_DATA_BLENDING\x10\x02\x12\x16\n\x12UNLABELED_DATA_SSL\x10\x03\x62\x06proto3'
    ),
    dependencies=[
        masterful_dot_proto_dot_layer__pb2.DESCRIPTOR,
        masterful_dot_proto_dot_metrics__pb2.DESCRIPTOR,
        masterful_dot_proto_dot_metadata__pb2.DESCRIPTOR,
    ])

_NODESEARCHTYPE = _descriptor.EnumDescriptor(
    name='NodeSearchType',
    full_name='NodeSearchType',
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(name='NODE_SEARCH_TYPE_UNKNOWN',
                                        index=0,
                                        number=0,
                                        serialized_options=None,
                                        type=None),
        _descriptor.EnumValueDescriptor(name='LAYER',
                                        index=1,
                                        number=1,
                                        serialized_options=None,
                                        type=None),
        _descriptor.EnumValueDescriptor(name='SYNTHETIC_DATA_BLENDING',
                                        index=2,
                                        number=2,
                                        serialized_options=None,
                                        type=None),
        _descriptor.EnumValueDescriptor(name='UNLABELED_DATA_SSL',
                                        index=3,
                                        number=3,
                                        serialized_options=None,
                                        type=None),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1103,
    serialized_end=1213,
)
_sym_db.RegisterEnumDescriptor(_NODESEARCHTYPE)

NodeSearchType = enum_type_wrapper.EnumTypeWrapper(_NODESEARCHTYPE)
NODE_SEARCH_TYPE_UNKNOWN = 0
LAYER = 1
SYNTHETIC_DATA_BLENDING = 2
UNLABELED_DATA_SSL = 3

_POLICYSEARCHTASK = _descriptor.Descriptor(
    name='PolicySearchTask',
    full_name='PolicySearchTask',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(name='policy_name',
                                    full_name='PolicySearchTask.policy_name',
                                    index=0,
                                    number=1,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='approach_name',
                                    full_name='PolicySearchTask.approach_name',
                                    index=1,
                                    number=2,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='node_search_tasks',
            full_name='PolicySearchTask.node_search_tasks',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='presearch_model_val_metrics',
            full_name='PolicySearchTask.presearch_model_val_metrics',
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='engine_version',
                                    full_name='PolicySearchTask.engine_version',
                                    index=4,
                                    number=5,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='fit_was_captured',
            full_name='PolicySearchTask.fit_was_captured',
            index=5,
            number=6,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='learned_policy_val_metrics',
            full_name='PolicySearchTask.learned_policy_val_metrics',
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='task_type',
                                    full_name='PolicySearchTask.task_type',
                                    index=7,
                                    number=8,
                                    type=14,
                                    cpp_type=8,
                                    label=1,
                                    has_default_value=False,
                                    default_value=0,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=130,
    serialized_end=419,
)

_NODESEARCHTASK_NODESCALARSMAPENTRY = _descriptor.Descriptor(
    name='NodeScalarsMapEntry',
    full_name='NodeSearchTask.NodeScalarsMapEntry',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='key',
            full_name='NodeSearchTask.NodeScalarsMapEntry.key',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='value',
            full_name='NodeSearchTask.NodeScalarsMapEntry.value',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b('8\001'),
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=749,
    serialized_end=816,
)

_NODESEARCHTASK_NODEOPTIMALSCALARMAPENTRY = _descriptor.Descriptor(
    name='NodeOptimalScalarMapEntry',
    full_name='NodeSearchTask.NodeOptimalScalarMapEntry',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='key',
            full_name='NodeSearchTask.NodeOptimalScalarMapEntry.key',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='value',
            full_name='NodeSearchTask.NodeOptimalScalarMapEntry.value',
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b('8\001'),
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=818,
    serialized_end=877,
)

_NODESEARCHTASK = _descriptor.Descriptor(
    name='NodeSearchTask',
    full_name='NodeSearchTask',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(name='type',
                                    full_name='NodeSearchTask.type',
                                    index=0,
                                    number=1,
                                    type=14,
                                    cpp_type=8,
                                    label=1,
                                    has_default_value=False,
                                    default_value=0,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='title',
                                    full_name='NodeSearchTask.title',
                                    index=1,
                                    number=2,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='searched_scalars',
                                    full_name='NodeSearchTask.searched_scalars',
                                    index=2,
                                    number=3,
                                    type=2,
                                    cpp_type=6,
                                    label=3,
                                    has_default_value=False,
                                    default_value=[],
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='optimal_scalar',
                                    full_name='NodeSearchTask.optimal_scalar',
                                    index=3,
                                    number=4,
                                    type=2,
                                    cpp_type=6,
                                    label=1,
                                    has_default_value=False,
                                    default_value=float(0),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='val_metrics',
                                    full_name='NodeSearchTask.val_metrics',
                                    index=4,
                                    number=5,
                                    type=11,
                                    cpp_type=10,
                                    label=3,
                                    has_default_value=False,
                                    default_value=[],
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='searched_layers',
                                    full_name='NodeSearchTask.searched_layers',
                                    index=5,
                                    number=6,
                                    type=11,
                                    cpp_type=10,
                                    label=3,
                                    has_default_value=False,
                                    default_value=[],
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='node_scalars_map',
                                    full_name='NodeSearchTask.node_scalars_map',
                                    index=6,
                                    number=7,
                                    type=11,
                                    cpp_type=10,
                                    label=3,
                                    has_default_value=False,
                                    default_value=[],
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='node_optimal_scalar_map',
            full_name='NodeSearchTask.node_optimal_scalar_map',
            index=7,
            number=8,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[
        _NODESEARCHTASK_NODESCALARSMAPENTRY,
        _NODESEARCHTASK_NODEOPTIMALSCALARMAPENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=422,
    serialized_end=877,
)

_NODESEARCHMETRICS_NODESCALARMAPENTRY = _descriptor.Descriptor(
    name='NodeScalarMapEntry',
    full_name='NodeSearchMetrics.NodeScalarMapEntry',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='key',
            full_name='NodeSearchMetrics.NodeScalarMapEntry.key',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='value',
            full_name='NodeSearchMetrics.NodeScalarMapEntry.value',
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b('8\001'),
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1017,
    serialized_end=1069,
)

_NODESEARCHMETRICS = _descriptor.Descriptor(
    name='NodeSearchMetrics',
    full_name='NodeSearchMetrics',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='searched_scalar',
            full_name='NodeSearchMetrics.searched_scalar',
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='metrics',
                                    full_name='NodeSearchMetrics.metrics',
                                    index=1,
                                    number=2,
                                    type=11,
                                    cpp_type=10,
                                    label=1,
                                    has_default_value=False,
                                    default_value=None,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='node_scalar_map',
            full_name='NodeSearchMetrics.node_scalar_map',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[
        _NODESEARCHMETRICS_NODESCALARMAPENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=880,
    serialized_end=1069,
)

_SCALARSLIST = _descriptor.Descriptor(
    name='ScalarsList',
    full_name='ScalarsList',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(name='scalars',
                                    full_name='ScalarsList.scalars',
                                    index=0,
                                    number=1,
                                    type=2,
                                    cpp_type=6,
                                    label=3,
                                    has_default_value=False,
                                    default_value=[],
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1071,
    serialized_end=1101,
)

_POLICYSEARCHTASK.fields_by_name[
    'node_search_tasks'].message_type = _NODESEARCHTASK
_POLICYSEARCHTASK.fields_by_name[
    'presearch_model_val_metrics'].message_type = masterful_dot_proto_dot_metrics__pb2._METRICS
_POLICYSEARCHTASK.fields_by_name[
    'learned_policy_val_metrics'].message_type = masterful_dot_proto_dot_metrics__pb2._METRICS
_POLICYSEARCHTASK.fields_by_name[
    'task_type'].enum_type = masterful_dot_proto_dot_metadata__pb2._COMPUTERVISIONTASK
_NODESEARCHTASK_NODESCALARSMAPENTRY.fields_by_name[
    'value'].message_type = _SCALARSLIST
_NODESEARCHTASK_NODESCALARSMAPENTRY.containing_type = _NODESEARCHTASK
_NODESEARCHTASK_NODEOPTIMALSCALARMAPENTRY.containing_type = _NODESEARCHTASK
_NODESEARCHTASK.fields_by_name['type'].enum_type = _NODESEARCHTYPE
_NODESEARCHTASK.fields_by_name['val_metrics'].message_type = _NODESEARCHMETRICS
_NODESEARCHTASK.fields_by_name[
    'searched_layers'].message_type = masterful_dot_proto_dot_layer__pb2._LAYER
_NODESEARCHTASK.fields_by_name[
    'node_scalars_map'].message_type = _NODESEARCHTASK_NODESCALARSMAPENTRY
_NODESEARCHTASK.fields_by_name[
    'node_optimal_scalar_map'].message_type = _NODESEARCHTASK_NODEOPTIMALSCALARMAPENTRY
_NODESEARCHMETRICS_NODESCALARMAPENTRY.containing_type = _NODESEARCHMETRICS
_NODESEARCHMETRICS.fields_by_name[
    'metrics'].message_type = masterful_dot_proto_dot_metrics__pb2._METRICS
_NODESEARCHMETRICS.fields_by_name[
    'node_scalar_map'].message_type = _NODESEARCHMETRICS_NODESCALARMAPENTRY
DESCRIPTOR.message_types_by_name['PolicySearchTask'] = _POLICYSEARCHTASK
DESCRIPTOR.message_types_by_name['NodeSearchTask'] = _NODESEARCHTASK
DESCRIPTOR.message_types_by_name['NodeSearchMetrics'] = _NODESEARCHMETRICS
DESCRIPTOR.message_types_by_name['ScalarsList'] = _SCALARSLIST
DESCRIPTOR.enum_types_by_name['NodeSearchType'] = _NODESEARCHTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PolicySearchTask = _reflection.GeneratedProtocolMessageType(
    'PolicySearchTask',
    (_message.Message,),
    {
        'DESCRIPTOR': _POLICYSEARCHTASK,
        '__module__': 'masterful.proto.search_task_pb2'
        # @@protoc_insertion_point(class_scope:PolicySearchTask)
    })
_sym_db.RegisterMessage(PolicySearchTask)

NodeSearchTask = _reflection.GeneratedProtocolMessageType(
    'NodeSearchTask',
    (_message.Message,),
    {
        'NodeScalarsMapEntry':
            _reflection.GeneratedProtocolMessageType(
                'NodeScalarsMapEntry',
                (_message.Message,),
                {
                    'DESCRIPTOR': _NODESEARCHTASK_NODESCALARSMAPENTRY,
                    '__module__': 'masterful.proto.search_task_pb2'
                    # @@protoc_insertion_point(class_scope:NodeSearchTask.NodeScalarsMapEntry)
                }),
        'NodeOptimalScalarMapEntry':
            _reflection.GeneratedProtocolMessageType(
                'NodeOptimalScalarMapEntry',
                (_message.Message,),
                {
                    'DESCRIPTOR': _NODESEARCHTASK_NODEOPTIMALSCALARMAPENTRY,
                    '__module__': 'masterful.proto.search_task_pb2'
                    # @@protoc_insertion_point(class_scope:NodeSearchTask.NodeOptimalScalarMapEntry)
                }),
        'DESCRIPTOR':
            _NODESEARCHTASK,
        '__module__':
            'masterful.proto.search_task_pb2'
        # @@protoc_insertion_point(class_scope:NodeSearchTask)
    })
_sym_db.RegisterMessage(NodeSearchTask)
_sym_db.RegisterMessage(NodeSearchTask.NodeScalarsMapEntry)
_sym_db.RegisterMessage(NodeSearchTask.NodeOptimalScalarMapEntry)

NodeSearchMetrics = _reflection.GeneratedProtocolMessageType(
    'NodeSearchMetrics',
    (_message.Message,),
    {
        'NodeScalarMapEntry':
            _reflection.GeneratedProtocolMessageType(
                'NodeScalarMapEntry',
                (_message.Message,),
                {
                    'DESCRIPTOR': _NODESEARCHMETRICS_NODESCALARMAPENTRY,
                    '__module__': 'masterful.proto.search_task_pb2'
                    # @@protoc_insertion_point(class_scope:NodeSearchMetrics.NodeScalarMapEntry)
                }),
        'DESCRIPTOR':
            _NODESEARCHMETRICS,
        '__module__':
            'masterful.proto.search_task_pb2'
        # @@protoc_insertion_point(class_scope:NodeSearchMetrics)
    })
_sym_db.RegisterMessage(NodeSearchMetrics)
_sym_db.RegisterMessage(NodeSearchMetrics.NodeScalarMapEntry)

ScalarsList = _reflection.GeneratedProtocolMessageType(
    'ScalarsList',
    (_message.Message,),
    {
        'DESCRIPTOR': _SCALARSLIST,
        '__module__': 'masterful.proto.search_task_pb2'
        # @@protoc_insertion_point(class_scope:ScalarsList)
    })
_sym_db.RegisterMessage(ScalarsList)

_NODESEARCHTASK_NODESCALARSMAPENTRY._options = None
_NODESEARCHTASK_NODEOPTIMALSCALARMAPENTRY._options = None
_NODESEARCHMETRICS_NODESCALARMAPENTRY._options = None
# @@protoc_insertion_point(module_scope)
