{% load render_bundle from webpack_loader %}
<!DOCTYPE html>
<html>

<head>
  <meta charset="UTF-8" />
  <meta name="viewport" content="width=device-width" />
  <title>Masterful AI GUI</title>
</head>

<body>
  <div id="root">
  </div>
  {% render_bundle 'main' %}
</body>

</html>