# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: masterful/proto/metrics.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='masterful/proto/metrics.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1dmasterful/proto/metrics.proto\"\xd9\x03\n\x07Metrics\x12\x0c\n\x04loss\x18\x01 \x01(\x02\x12\x36\n\x10label_recall_map\x18\x02 \x03(\x0b\x32\x1c.Metrics.LabelRecallMapEntry\x12<\n\x13label_precision_map\x18\x03 \x03(\x0b\x32\x1f.Metrics.LabelPrecisionMapEntry\x12\x37\n\x10\x63onfusion_matrix\x18\x04 \x03(\x0b\x32\x1d.Metrics.ConfusionMatrixEntry\x12\x15\n\rbinary_recall\x18\x05 \x01(\x02\x12\x18\n\x10\x62inary_precision\x18\x06 \x01(\x02\x12\x17\n\x0f\x62inary_f1_score\x18\x07 \x01(\x02\x12\x12\n\nerror_rate\x18\x08 \x01(\x02\x1a\x35\n\x13LabelRecallMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1a\x38\n\x16LabelPrecisionMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1a\x42\n\x14\x43onfusionMatrixEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x19\n\x05value\x18\x02 \x01(\x0b\x32\n.Int32List:\x02\x38\x01\"\x1b\n\tInt32List\x12\x0e\n\x06values\x18\x01 \x03(\x05\x62\x06proto3')
)




_METRICS_LABELRECALLMAPENTRY = _descriptor.Descriptor(
  name='LabelRecallMapEntry',
  full_name='Metrics.LabelRecallMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Metrics.LabelRecallMapEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='Metrics.LabelRecallMapEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=381,
)

_METRICS_LABELPRECISIONMAPENTRY = _descriptor.Descriptor(
  name='LabelPrecisionMapEntry',
  full_name='Metrics.LabelPrecisionMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Metrics.LabelPrecisionMapEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='Metrics.LabelPrecisionMapEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=383,
  serialized_end=439,
)

_METRICS_CONFUSIONMATRIXENTRY = _descriptor.Descriptor(
  name='ConfusionMatrixEntry',
  full_name='Metrics.ConfusionMatrixEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Metrics.ConfusionMatrixEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='Metrics.ConfusionMatrixEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=441,
  serialized_end=507,
)

_METRICS = _descriptor.Descriptor(
  name='Metrics',
  full_name='Metrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='loss', full_name='Metrics.loss', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_recall_map', full_name='Metrics.label_recall_map', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_precision_map', full_name='Metrics.label_precision_map', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='confusion_matrix', full_name='Metrics.confusion_matrix', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary_recall', full_name='Metrics.binary_recall', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary_precision', full_name='Metrics.binary_precision', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary_f1_score', full_name='Metrics.binary_f1_score', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_rate', full_name='Metrics.error_rate', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_METRICS_LABELRECALLMAPENTRY, _METRICS_LABELPRECISIONMAPENTRY, _METRICS_CONFUSIONMATRIXENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=507,
)


_INT32LIST = _descriptor.Descriptor(
  name='Int32List',
  full_name='Int32List',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='Int32List.values', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=509,
  serialized_end=536,
)

_METRICS_LABELRECALLMAPENTRY.containing_type = _METRICS
_METRICS_LABELPRECISIONMAPENTRY.containing_type = _METRICS
_METRICS_CONFUSIONMATRIXENTRY.fields_by_name['value'].message_type = _INT32LIST
_METRICS_CONFUSIONMATRIXENTRY.containing_type = _METRICS
_METRICS.fields_by_name['label_recall_map'].message_type = _METRICS_LABELRECALLMAPENTRY
_METRICS.fields_by_name['label_precision_map'].message_type = _METRICS_LABELPRECISIONMAPENTRY
_METRICS.fields_by_name['confusion_matrix'].message_type = _METRICS_CONFUSIONMATRIXENTRY
DESCRIPTOR.message_types_by_name['Metrics'] = _METRICS
DESCRIPTOR.message_types_by_name['Int32List'] = _INT32LIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Metrics = _reflection.GeneratedProtocolMessageType('Metrics', (_message.Message,), {

  'LabelRecallMapEntry' : _reflection.GeneratedProtocolMessageType('LabelRecallMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _METRICS_LABELRECALLMAPENTRY,
    '__module__' : 'masterful.proto.metrics_pb2'
    # @@protoc_insertion_point(class_scope:Metrics.LabelRecallMapEntry)
    })
  ,

  'LabelPrecisionMapEntry' : _reflection.GeneratedProtocolMessageType('LabelPrecisionMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _METRICS_LABELPRECISIONMAPENTRY,
    '__module__' : 'masterful.proto.metrics_pb2'
    # @@protoc_insertion_point(class_scope:Metrics.LabelPrecisionMapEntry)
    })
  ,

  'ConfusionMatrixEntry' : _reflection.GeneratedProtocolMessageType('ConfusionMatrixEntry', (_message.Message,), {
    'DESCRIPTOR' : _METRICS_CONFUSIONMATRIXENTRY,
    '__module__' : 'masterful.proto.metrics_pb2'
    # @@protoc_insertion_point(class_scope:Metrics.ConfusionMatrixEntry)
    })
  ,
  'DESCRIPTOR' : _METRICS,
  '__module__' : 'masterful.proto.metrics_pb2'
  # @@protoc_insertion_point(class_scope:Metrics)
  })
_sym_db.RegisterMessage(Metrics)
_sym_db.RegisterMessage(Metrics.LabelRecallMapEntry)
_sym_db.RegisterMessage(Metrics.LabelPrecisionMapEntry)
_sym_db.RegisterMessage(Metrics.ConfusionMatrixEntry)

Int32List = _reflection.GeneratedProtocolMessageType('Int32List', (_message.Message,), {
  'DESCRIPTOR' : _INT32LIST,
  '__module__' : 'masterful.proto.metrics_pb2'
  # @@protoc_insertion_point(class_scope:Int32List)
  })
_sym_db.RegisterMessage(Int32List)


_METRICS_LABELRECALLMAPENTRY._options = None
_METRICS_LABELPRECISIONMAPENTRY._options = None
_METRICS_CONFUSIONMATRIXENTRY._options = None
# @@protoc_insertion_point(module_scope)
