# Generated by Django 3.2 on 2021-09-18 16:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0004_auto_20210917_1440'),
    ]

    operations = [
        migrations.AddField(
            model_name='policysearchtask',
            name='engine_version',
            field=models.CharField(default='', max_length=100),
        ),
    ]
