# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: masterful/proto/dataset.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from masterful_gui.backend.proto import metadata_pb2 as masterful_dot_proto_dot_metadata__pb2
from masterful_gui.backend.proto import params_pb2 as masterful_dot_proto_dot_params__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='masterful/proto/dataset.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1dmasterful/proto/dataset.proto\x1a\x1emasterful/proto/metadata.proto\x1a\x1cmasterful/proto/params.proto\"\x9d\x02\n\x07\x44\x61taset\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05split\x18\x03 \x01(\t\x12\x13\n\x0bnum_classes\x18\x04 \x01(\x05\x12\x0f\n\x07\x63v_task\x18\x05 \x01(\t\x12\x13\n\x0b\x63\x61rdinality\x18\x06 \x01(\x03\x12+\n\nlabels_map\x18\x07 \x03(\x0b\x32\x17.Dataset.LabelsMapEntry\x12\x31\n\x10\x61nalysis_results\x18\x08 \x01(\x0b\x32\x17.DatasetAnalysisResults\x12\x1b\n\x06params\x18\t \x01(\x0b\x32\x0b.DataParams\x1a\x30\n\x0eLabelsMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xea\x05\n\x16\x44\x61tasetAnalysisResults\x12\x16\n\x0etotal_examples\x18\x01 \x01(\x03\x12>\n\x0clabel_counts\x18\x02 \x03(\x0b\x32(.DatasetAnalysisResults.LabelCountsEntry\x12L\n\x13label_distributions\x18\x03 \x03(\x0b\x32/.DatasetAnalysisResults.LabelDistributionsEntry\x12\x10\n\x08\x62\x61lanced\x18\x04 \x01(\t\x12\x12\n\nmin_height\x18\x05 \x01(\x05\x12\x11\n\tmin_width\x18\x06 \x01(\x05\x12\x12\n\nmax_height\x18\x07 \x01(\x05\x12\x11\n\tmax_width\x18\x08 \x01(\x05\x12\x12\n\navg_height\x18\t \x01(\x05\x12\x11\n\tavg_width\x18\n \x01(\x05\x12\x15\n\rlargest_image\x18\x0b \x01(\t\x12\x16\n\x0esmallest_image\x18\x0c \x01(\t\x12\x17\n\x0f\x61vg_object_area\x18\r \x01(\t\x12\x1c\n\x14smallest_object_area\x18\x0e \x01(\t\x12\x1b\n\x13largest_object_area\x18\x0f \x01(\t\x12\x19\n\x11num_small_objects\x18\x10 \x01(\x03\x12\x1a\n\x12num_medium_objects\x18\x11 \x01(\x03\x12\x19\n\x11num_large_objects\x18\x12 \x01(\x03\x12\x18\n\x10num_empty_images\x18\x13 \x01(\x03\x12\x15\n\rtotal_objects\x18\x14 \x01(\x03\x12.\n\x12\x64uplicate_analysis\x18\x15 \x01(\x0b\x32\x12.DuplicateAnalysis\x1a\x32\n\x10LabelCountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x39\n\x17LabelDistributionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"q\n\x11\x44uplicateAnalysis\x12\x12\n\nduplicates\x18\x01 \x03(\t\x12\x18\n\x10\x64uplicates_count\x18\x02 \x01(\x05\x12\x17\n\x0fimage_path_type\x18\x03 \x01(\t\x12\x15\n\rduration_mins\x18\x04 \x01(\x05\"\xbb\x04\n\x05Split\x12$\n\nsplit_type\x18\x01 \x01(\x0e\x32\x10.Split.SplitType\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x63\x61rdinality\x18\x03 \x01(\x03\x12+\n\x0blabel_count\x18\x04 \x03(\x0b\x32\x16.Split.LabelCountEntry\x12\x39\n\x12label_distribution\x18\x05 \x03(\x0b\x32\x1d.Split.LabelDistributionEntry\x12\x1e\n\nimage_spec\x18\x06 \x01(\x0b\x32\n.ImageSpec\x12\x13\n\x0bnum_classes\x18\x07 \x01(\x05\x12\x12\n\nimbalanced\x18\x08 \x01(\x08\x12\x18\n\x10\x64uplicates_count\x18\t \x01(\x03\x12/\n\rimage_samples\x18\n \x03(\x0b\x32\x18.Split.ImageSamplesEntry\x1a\x31\n\x0fLabelCountEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x38\n\x16LabelDistributionEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x1a\x33\n\x11ImageSamplesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"J\n\tSplitType\x12\x16\n\x12SPLIT_TYPE_UNKNOWN\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\t\n\x05TRAIN\x10\x02\x12\x07\n\x03VAL\x10\x03\x12\x08\n\x04TEST\x10\x04\"\xdc\x03\n\rDatasetLegacy\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x1d\n\rtrain_dataset\x18\x03 \x01(\x0b\x32\x06.Split\x12\x1b\n\x0bval_dataset\x18\x04 \x01(\x0b\x32\x06.Split\x12\x1c\n\x0ctest_dataset\x18\x05 \x01(\x0b\x32\x06.Split\x12\x1c\n\x0c\x66ull_dataset\x18\x06 \x01(\x0b\x32\x06.Split\x12\x13\n\x0b\x63\x61rdinality\x18\x07 \x01(\x03\x12\x33\n\x0blabel_count\x18\x08 \x03(\x0b\x32\x1e.DatasetLegacy.LabelCountEntry\x12\x31\n\nlabels_map\x18\t \x03(\x0b\x32\x1d.DatasetLegacy.LabelsMapEntry\x12!\n\x04task\x18\n \x01(\x0e\x32\x13.ComputerVisionTask\x12\x13\n\x0bnum_classes\x18\x0b \x01(\x05\x12\x1e\n\x16\x61nalysis_duration_mins\x18\x0c \x01(\x02\x1a\x31\n\x0fLabelCountEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x30\n\x0eLabelsMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')
  ,
  dependencies=[masterful_dot_proto_dot_metadata__pb2.DESCRIPTOR,masterful_dot_proto_dot_params__pb2.DESCRIPTOR,])



_SPLIT_SPLITTYPE = _descriptor.EnumDescriptor(
  name='SplitType',
  full_name='Split.SplitType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SPLIT_TYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRAIN', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VAL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEST', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1745,
  serialized_end=1819,
)
_sym_db.RegisterEnumDescriptor(_SPLIT_SPLITTYPE)


_DATASET_LABELSMAPENTRY = _descriptor.Descriptor(
  name='LabelsMapEntry',
  full_name='Dataset.LabelsMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Dataset.LabelsMapEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='Dataset.LabelsMapEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=381,
)

_DATASET = _descriptor.Descriptor(
  name='Dataset',
  full_name='Dataset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Dataset.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='Dataset.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='split', full_name='Dataset.split', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_classes', full_name='Dataset.num_classes', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cv_task', full_name='Dataset.cv_task', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cardinality', full_name='Dataset.cardinality', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels_map', full_name='Dataset.labels_map', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='analysis_results', full_name='Dataset.analysis_results', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='params', full_name='Dataset.params', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DATASET_LABELSMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=381,
)


_DATASETANALYSISRESULTS_LABELCOUNTSENTRY = _descriptor.Descriptor(
  name='LabelCountsEntry',
  full_name='DatasetAnalysisResults.LabelCountsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='DatasetAnalysisResults.LabelCountsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='DatasetAnalysisResults.LabelCountsEntry.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1021,
  serialized_end=1071,
)

_DATASETANALYSISRESULTS_LABELDISTRIBUTIONSENTRY = _descriptor.Descriptor(
  name='LabelDistributionsEntry',
  full_name='DatasetAnalysisResults.LabelDistributionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='DatasetAnalysisResults.LabelDistributionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='DatasetAnalysisResults.LabelDistributionsEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1073,
  serialized_end=1130,
)

_DATASETANALYSISRESULTS = _descriptor.Descriptor(
  name='DatasetAnalysisResults',
  full_name='DatasetAnalysisResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_examples', full_name='DatasetAnalysisResults.total_examples', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_counts', full_name='DatasetAnalysisResults.label_counts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_distributions', full_name='DatasetAnalysisResults.label_distributions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='balanced', full_name='DatasetAnalysisResults.balanced', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_height', full_name='DatasetAnalysisResults.min_height', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_width', full_name='DatasetAnalysisResults.min_width', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_height', full_name='DatasetAnalysisResults.max_height', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_width', full_name='DatasetAnalysisResults.max_width', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_height', full_name='DatasetAnalysisResults.avg_height', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_width', full_name='DatasetAnalysisResults.avg_width', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='largest_image', full_name='DatasetAnalysisResults.largest_image', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='smallest_image', full_name='DatasetAnalysisResults.smallest_image', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avg_object_area', full_name='DatasetAnalysisResults.avg_object_area', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='smallest_object_area', full_name='DatasetAnalysisResults.smallest_object_area', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='largest_object_area', full_name='DatasetAnalysisResults.largest_object_area', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_small_objects', full_name='DatasetAnalysisResults.num_small_objects', index=15,
      number=16, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_medium_objects', full_name='DatasetAnalysisResults.num_medium_objects', index=16,
      number=17, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_large_objects', full_name='DatasetAnalysisResults.num_large_objects', index=17,
      number=18, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_empty_images', full_name='DatasetAnalysisResults.num_empty_images', index=18,
      number=19, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_objects', full_name='DatasetAnalysisResults.total_objects', index=19,
      number=20, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duplicate_analysis', full_name='DatasetAnalysisResults.duplicate_analysis', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DATASETANALYSISRESULTS_LABELCOUNTSENTRY, _DATASETANALYSISRESULTS_LABELDISTRIBUTIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=384,
  serialized_end=1130,
)


_DUPLICATEANALYSIS = _descriptor.Descriptor(
  name='DuplicateAnalysis',
  full_name='DuplicateAnalysis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='duplicates', full_name='DuplicateAnalysis.duplicates', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duplicates_count', full_name='DuplicateAnalysis.duplicates_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_path_type', full_name='DuplicateAnalysis.image_path_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration_mins', full_name='DuplicateAnalysis.duration_mins', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1132,
  serialized_end=1245,
)


_SPLIT_LABELCOUNTENTRY = _descriptor.Descriptor(
  name='LabelCountEntry',
  full_name='Split.LabelCountEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Split.LabelCountEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='Split.LabelCountEntry.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1583,
  serialized_end=1632,
)

_SPLIT_LABELDISTRIBUTIONENTRY = _descriptor.Descriptor(
  name='LabelDistributionEntry',
  full_name='Split.LabelDistributionEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Split.LabelDistributionEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='Split.LabelDistributionEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1634,
  serialized_end=1690,
)

_SPLIT_IMAGESAMPLESENTRY = _descriptor.Descriptor(
  name='ImageSamplesEntry',
  full_name='Split.ImageSamplesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Split.ImageSamplesEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='Split.ImageSamplesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1692,
  serialized_end=1743,
)

_SPLIT = _descriptor.Descriptor(
  name='Split',
  full_name='Split',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='split_type', full_name='Split.split_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='Split.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cardinality', full_name='Split.cardinality', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_count', full_name='Split.label_count', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_distribution', full_name='Split.label_distribution', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_spec', full_name='Split.image_spec', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_classes', full_name='Split.num_classes', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='imbalanced', full_name='Split.imbalanced', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duplicates_count', full_name='Split.duplicates_count', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_samples', full_name='Split.image_samples', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SPLIT_LABELCOUNTENTRY, _SPLIT_LABELDISTRIBUTIONENTRY, _SPLIT_IMAGESAMPLESENTRY, ],
  enum_types=[
    _SPLIT_SPLITTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1248,
  serialized_end=1819,
)


_DATASETLEGACY_LABELCOUNTENTRY = _descriptor.Descriptor(
  name='LabelCountEntry',
  full_name='DatasetLegacy.LabelCountEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='DatasetLegacy.LabelCountEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='DatasetLegacy.LabelCountEntry.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1583,
  serialized_end=1632,
)

_DATASETLEGACY_LABELSMAPENTRY = _descriptor.Descriptor(
  name='LabelsMapEntry',
  full_name='DatasetLegacy.LabelsMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='DatasetLegacy.LabelsMapEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='DatasetLegacy.LabelsMapEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=381,
)

_DATASETLEGACY = _descriptor.Descriptor(
  name='DatasetLegacy',
  full_name='DatasetLegacy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='DatasetLegacy.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='DatasetLegacy.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='train_dataset', full_name='DatasetLegacy.train_dataset', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val_dataset', full_name='DatasetLegacy.val_dataset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='test_dataset', full_name='DatasetLegacy.test_dataset', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='full_dataset', full_name='DatasetLegacy.full_dataset', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cardinality', full_name='DatasetLegacy.cardinality', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_count', full_name='DatasetLegacy.label_count', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels_map', full_name='DatasetLegacy.labels_map', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='task', full_name='DatasetLegacy.task', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_classes', full_name='DatasetLegacy.num_classes', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='analysis_duration_mins', full_name='DatasetLegacy.analysis_duration_mins', index=11,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DATASETLEGACY_LABELCOUNTENTRY, _DATASETLEGACY_LABELSMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1822,
  serialized_end=2298,
)

_DATASET_LABELSMAPENTRY.containing_type = _DATASET
_DATASET.fields_by_name['labels_map'].message_type = _DATASET_LABELSMAPENTRY
_DATASET.fields_by_name['analysis_results'].message_type = _DATASETANALYSISRESULTS
_DATASET.fields_by_name['params'].message_type = masterful_dot_proto_dot_params__pb2._DATAPARAMS
_DATASETANALYSISRESULTS_LABELCOUNTSENTRY.containing_type = _DATASETANALYSISRESULTS
_DATASETANALYSISRESULTS_LABELDISTRIBUTIONSENTRY.containing_type = _DATASETANALYSISRESULTS
_DATASETANALYSISRESULTS.fields_by_name['label_counts'].message_type = _DATASETANALYSISRESULTS_LABELCOUNTSENTRY
_DATASETANALYSISRESULTS.fields_by_name['label_distributions'].message_type = _DATASETANALYSISRESULTS_LABELDISTRIBUTIONSENTRY
_DATASETANALYSISRESULTS.fields_by_name['duplicate_analysis'].message_type = _DUPLICATEANALYSIS
_SPLIT_LABELCOUNTENTRY.containing_type = _SPLIT
_SPLIT_LABELDISTRIBUTIONENTRY.containing_type = _SPLIT
_SPLIT_IMAGESAMPLESENTRY.containing_type = _SPLIT
_SPLIT.fields_by_name['split_type'].enum_type = _SPLIT_SPLITTYPE
_SPLIT.fields_by_name['label_count'].message_type = _SPLIT_LABELCOUNTENTRY
_SPLIT.fields_by_name['label_distribution'].message_type = _SPLIT_LABELDISTRIBUTIONENTRY
_SPLIT.fields_by_name['image_spec'].message_type = masterful_dot_proto_dot_metadata__pb2._IMAGESPEC
_SPLIT.fields_by_name['image_samples'].message_type = _SPLIT_IMAGESAMPLESENTRY
_SPLIT_SPLITTYPE.containing_type = _SPLIT
_DATASETLEGACY_LABELCOUNTENTRY.containing_type = _DATASETLEGACY
_DATASETLEGACY_LABELSMAPENTRY.containing_type = _DATASETLEGACY
_DATASETLEGACY.fields_by_name['train_dataset'].message_type = _SPLIT
_DATASETLEGACY.fields_by_name['val_dataset'].message_type = _SPLIT
_DATASETLEGACY.fields_by_name['test_dataset'].message_type = _SPLIT
_DATASETLEGACY.fields_by_name['full_dataset'].message_type = _SPLIT
_DATASETLEGACY.fields_by_name['label_count'].message_type = _DATASETLEGACY_LABELCOUNTENTRY
_DATASETLEGACY.fields_by_name['labels_map'].message_type = _DATASETLEGACY_LABELSMAPENTRY
_DATASETLEGACY.fields_by_name['task'].enum_type = masterful_dot_proto_dot_metadata__pb2._COMPUTERVISIONTASK
DESCRIPTOR.message_types_by_name['Dataset'] = _DATASET
DESCRIPTOR.message_types_by_name['DatasetAnalysisResults'] = _DATASETANALYSISRESULTS
DESCRIPTOR.message_types_by_name['DuplicateAnalysis'] = _DUPLICATEANALYSIS
DESCRIPTOR.message_types_by_name['Split'] = _SPLIT
DESCRIPTOR.message_types_by_name['DatasetLegacy'] = _DATASETLEGACY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Dataset = _reflection.GeneratedProtocolMessageType('Dataset', (_message.Message,), {

  'LabelsMapEntry' : _reflection.GeneratedProtocolMessageType('LabelsMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASET_LABELSMAPENTRY,
    '__module__' : 'masterful.proto.dataset_pb2'
    # @@protoc_insertion_point(class_scope:Dataset.LabelsMapEntry)
    })
  ,
  'DESCRIPTOR' : _DATASET,
  '__module__' : 'masterful.proto.dataset_pb2'
  # @@protoc_insertion_point(class_scope:Dataset)
  })
_sym_db.RegisterMessage(Dataset)
_sym_db.RegisterMessage(Dataset.LabelsMapEntry)

DatasetAnalysisResults = _reflection.GeneratedProtocolMessageType('DatasetAnalysisResults', (_message.Message,), {

  'LabelCountsEntry' : _reflection.GeneratedProtocolMessageType('LabelCountsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETANALYSISRESULTS_LABELCOUNTSENTRY,
    '__module__' : 'masterful.proto.dataset_pb2'
    # @@protoc_insertion_point(class_scope:DatasetAnalysisResults.LabelCountsEntry)
    })
  ,

  'LabelDistributionsEntry' : _reflection.GeneratedProtocolMessageType('LabelDistributionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETANALYSISRESULTS_LABELDISTRIBUTIONSENTRY,
    '__module__' : 'masterful.proto.dataset_pb2'
    # @@protoc_insertion_point(class_scope:DatasetAnalysisResults.LabelDistributionsEntry)
    })
  ,
  'DESCRIPTOR' : _DATASETANALYSISRESULTS,
  '__module__' : 'masterful.proto.dataset_pb2'
  # @@protoc_insertion_point(class_scope:DatasetAnalysisResults)
  })
_sym_db.RegisterMessage(DatasetAnalysisResults)
_sym_db.RegisterMessage(DatasetAnalysisResults.LabelCountsEntry)
_sym_db.RegisterMessage(DatasetAnalysisResults.LabelDistributionsEntry)

DuplicateAnalysis = _reflection.GeneratedProtocolMessageType('DuplicateAnalysis', (_message.Message,), {
  'DESCRIPTOR' : _DUPLICATEANALYSIS,
  '__module__' : 'masterful.proto.dataset_pb2'
  # @@protoc_insertion_point(class_scope:DuplicateAnalysis)
  })
_sym_db.RegisterMessage(DuplicateAnalysis)

Split = _reflection.GeneratedProtocolMessageType('Split', (_message.Message,), {

  'LabelCountEntry' : _reflection.GeneratedProtocolMessageType('LabelCountEntry', (_message.Message,), {
    'DESCRIPTOR' : _SPLIT_LABELCOUNTENTRY,
    '__module__' : 'masterful.proto.dataset_pb2'
    # @@protoc_insertion_point(class_scope:Split.LabelCountEntry)
    })
  ,

  'LabelDistributionEntry' : _reflection.GeneratedProtocolMessageType('LabelDistributionEntry', (_message.Message,), {
    'DESCRIPTOR' : _SPLIT_LABELDISTRIBUTIONENTRY,
    '__module__' : 'masterful.proto.dataset_pb2'
    # @@protoc_insertion_point(class_scope:Split.LabelDistributionEntry)
    })
  ,

  'ImageSamplesEntry' : _reflection.GeneratedProtocolMessageType('ImageSamplesEntry', (_message.Message,), {
    'DESCRIPTOR' : _SPLIT_IMAGESAMPLESENTRY,
    '__module__' : 'masterful.proto.dataset_pb2'
    # @@protoc_insertion_point(class_scope:Split.ImageSamplesEntry)
    })
  ,
  'DESCRIPTOR' : _SPLIT,
  '__module__' : 'masterful.proto.dataset_pb2'
  # @@protoc_insertion_point(class_scope:Split)
  })
_sym_db.RegisterMessage(Split)
_sym_db.RegisterMessage(Split.LabelCountEntry)
_sym_db.RegisterMessage(Split.LabelDistributionEntry)
_sym_db.RegisterMessage(Split.ImageSamplesEntry)

DatasetLegacy = _reflection.GeneratedProtocolMessageType('DatasetLegacy', (_message.Message,), {

  'LabelCountEntry' : _reflection.GeneratedProtocolMessageType('LabelCountEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETLEGACY_LABELCOUNTENTRY,
    '__module__' : 'masterful.proto.dataset_pb2'
    # @@protoc_insertion_point(class_scope:DatasetLegacy.LabelCountEntry)
    })
  ,

  'LabelsMapEntry' : _reflection.GeneratedProtocolMessageType('LabelsMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETLEGACY_LABELSMAPENTRY,
    '__module__' : 'masterful.proto.dataset_pb2'
    # @@protoc_insertion_point(class_scope:DatasetLegacy.LabelsMapEntry)
    })
  ,
  'DESCRIPTOR' : _DATASETLEGACY,
  '__module__' : 'masterful.proto.dataset_pb2'
  # @@protoc_insertion_point(class_scope:DatasetLegacy)
  })
_sym_db.RegisterMessage(DatasetLegacy)
_sym_db.RegisterMessage(DatasetLegacy.LabelCountEntry)
_sym_db.RegisterMessage(DatasetLegacy.LabelsMapEntry)


_DATASET_LABELSMAPENTRY._options = None
_DATASETANALYSISRESULTS_LABELCOUNTSENTRY._options = None
_DATASETANALYSISRESULTS_LABELDISTRIBUTIONSENTRY._options = None
_SPLIT_LABELCOUNTENTRY._options = None
_SPLIT_LABELDISTRIBUTIONENTRY._options = None
_SPLIT_IMAGESAMPLESENTRY._options = None
_DATASETLEGACY_LABELCOUNTENTRY._options = None
_DATASETLEGACY_LABELSMAPENTRY._options = None
# @@protoc_insertion_point(module_scope)
