# Generated by Django 3.2.8 on 2022-04-27 14:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0007_policysearchtask_task_type'),
    ]

    operations = [
        migrations.CreateModel(
            name='Dataset',
            fields=[
                ('dataset_id', models.CharField(max_length=250, primary_key=True, serialize=False)),
                ('title', models.CharField(max_length=250)),
                ('train_dataset', models.JSONField(default=dict)),
                ('val_dataset', models.JSONField(default=dict)),
                ('test_dataset', models.JSONField(default=dict)),
                ('full_dataset', models.JSONField(default=dict)),
                ('cardinality', models.IntegerField(default=0)),
                ('label_count', models.JSONField(default=dict)),
                ('labels_map', models.JSONField(default=dict)),
                ('task', models.JSONField(default=dict)),
                ('num_classes', models.IntegerField(default=0)),
                ('analysis_duration_mins', models.FloatField(default=0.0)),
            ],
        ),
        migrations.DeleteModel(
            name='DatasetSpec',
        ),
    ]
