# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: masterful/proto/training.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from masterful_gui.backend.proto import timestamp_pb2 as masterful_dot_proto_dot_timestamp__pb2
from masterful_gui.backend.proto import model_pb2 as masterful_dot_proto_dot_model__pb2
from masterful_gui.backend.proto import search_task_pb2 as masterful_dot_proto_dot_search__task__pb2
from masterful_gui.backend.proto import params_pb2 as masterful_dot_proto_dot_params__pb2
from masterful_gui.backend.proto import dataset_pb2 as masterful_dot_proto_dot_dataset__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='masterful/proto/training.proto',
    package='',
    syntax='proto3',
    serialized_options=None,
    serialized_pb=_b(
        '\n\x1emasterful/proto/training.proto\x1a\x1fmasterful/proto/timestamp.proto\x1a\x1bmasterful/proto/model.proto\x1a!masterful/proto/search_task.proto\x1a\x1cmasterful/proto/params.proto\x1a\x1dmasterful/proto/dataset.proto\"\xe1\x02\n\x0bTrainingRun\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x0c\x63ompleted_ts\x18\x02 \x01(\x0b\x32\n.Timestamp\x12\x1a\n\nmodel_info\x18\x03 \x01(\x0b\x32\x06.Model\x12\x30\n\x15policy_search_results\x18\x04 \x01(\x0b\x32\x11.PolicySearchTask\x12\x15\n\rapproach_name\x18\x05 \x01(\t\x12\x19\n\x11masterful_version\x18\x06 \x01(\t\x12\x0c\n\x04task\x18\x07 \x01(\t\x12\x30\n\x13optimization_params\x18\x08 \x01(\x0b\x32\x13.OptimizationParams\x12\x1e\n\nssl_params\x18\t \x01(\x0b\x32\n.SslParams\x12\x1a\n\x08\x64\x61tasets\x18\n \x03(\x0b\x32\x08.Dataset\x12\x14\n\x0csource_split\x18\x0b \x01(\t\x12\x10\n\x08with_cli\x18\x0c \x01(\x08\x62\x06proto3'
    ),
    dependencies=[
        masterful_dot_proto_dot_timestamp__pb2.DESCRIPTOR,
        masterful_dot_proto_dot_model__pb2.DESCRIPTOR,
        masterful_dot_proto_dot_search__task__pb2.DESCRIPTOR,
        masterful_dot_proto_dot_params__pb2.DESCRIPTOR,
        masterful_dot_proto_dot_dataset__pb2.DESCRIPTOR,
    ])

_TRAININGRUN = _descriptor.Descriptor(
    name='TrainingRun',
    full_name='TrainingRun',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(name='name',
                                    full_name='TrainingRun.name',
                                    index=0,
                                    number=1,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='completed_ts',
                                    full_name='TrainingRun.completed_ts',
                                    index=1,
                                    number=2,
                                    type=11,
                                    cpp_type=10,
                                    label=1,
                                    has_default_value=False,
                                    default_value=None,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='model_info',
                                    full_name='TrainingRun.model_info',
                                    index=2,
                                    number=3,
                                    type=11,
                                    cpp_type=10,
                                    label=1,
                                    has_default_value=False,
                                    default_value=None,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='policy_search_results',
            full_name='TrainingRun.policy_search_results',
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='approach_name',
                                    full_name='TrainingRun.approach_name',
                                    index=4,
                                    number=5,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='masterful_version',
                                    full_name='TrainingRun.masterful_version',
                                    index=5,
                                    number=6,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='task',
                                    full_name='TrainingRun.task',
                                    index=6,
                                    number=7,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='optimization_params',
                                    full_name='TrainingRun.optimization_params',
                                    index=7,
                                    number=8,
                                    type=11,
                                    cpp_type=10,
                                    label=1,
                                    has_default_value=False,
                                    default_value=None,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='ssl_params',
                                    full_name='TrainingRun.ssl_params',
                                    index=8,
                                    number=9,
                                    type=11,
                                    cpp_type=10,
                                    label=1,
                                    has_default_value=False,
                                    default_value=None,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='datasets',
                                    full_name='TrainingRun.datasets',
                                    index=9,
                                    number=10,
                                    type=11,
                                    cpp_type=10,
                                    label=3,
                                    has_default_value=False,
                                    default_value=[],
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='source_split',
                                    full_name='TrainingRun.source_split',
                                    index=10,
                                    number=11,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='with_cli',
                                    full_name='TrainingRun.with_cli',
                                    index=11,
                                    number=12,
                                    type=8,
                                    cpp_type=7,
                                    label=1,
                                    has_default_value=False,
                                    default_value=False,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=193,
    serialized_end=546,
)

_TRAININGRUN.fields_by_name[
    'completed_ts'].message_type = masterful_dot_proto_dot_timestamp__pb2._TIMESTAMP
_TRAININGRUN.fields_by_name[
    'model_info'].message_type = masterful_dot_proto_dot_model__pb2._MODEL
_TRAININGRUN.fields_by_name[
    'policy_search_results'].message_type = masterful_dot_proto_dot_search__task__pb2._POLICYSEARCHTASK
_TRAININGRUN.fields_by_name[
    'optimization_params'].message_type = masterful_dot_proto_dot_params__pb2._OPTIMIZATIONPARAMS
_TRAININGRUN.fields_by_name[
    'ssl_params'].message_type = masterful_dot_proto_dot_params__pb2._SSLPARAMS
_TRAININGRUN.fields_by_name[
    'datasets'].message_type = masterful_dot_proto_dot_dataset__pb2._DATASET
DESCRIPTOR.message_types_by_name['TrainingRun'] = _TRAININGRUN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TrainingRun = _reflection.GeneratedProtocolMessageType(
    'TrainingRun',
    (_message.Message,),
    {
        'DESCRIPTOR': _TRAININGRUN,
        '__module__': 'masterful.proto.training_pb2'
        # @@protoc_insertion_point(class_scope:TrainingRun)
    })
_sym_db.RegisterMessage(TrainingRun)

# @@protoc_insertion_point(module_scope)
