# Generated by Django 3.2.8 on 2022-07-27 14:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0011_trainingrun_model_graph_image'),
    ]

    operations = [
        migrations.AddField(
            model_name='trainingrun',
            name='optimization_params',
            field=models.JSONField(default=dict),
        ),
        migrations.AddField(
            model_name='trainingrun',
            name='ssl_params',
            field=models.JSONField(default=dict),
        ),
    ]
