# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: masterful/proto/model.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from masterful_gui.backend.proto import params_pb2 as masterful_dot_proto_dot_params__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='masterful/proto/model.proto',
    package='',
    syntax='proto3',
    serialized_options=None,
    serialized_pb=_b(
        '\n\x1bmasterful/proto/model.proto\x1a\x1cmasterful/proto/params.proto\"\x89\x01\n\x05Model\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x30\n\x13\x61rchitecture_params\x18\x02 \x01(\x0b\x32\x13.ArchitectureParams\x12\x19\n\x07summary\x18\x03 \x01(\x0b\x32\x08.Summary\x12%\n\x0bgraph_image\x18\x04 \x01(\x0b\x32\x10.ModelGraphImage\"i\n\nSummaryRow\x12\r\n\x05layer\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x14\n\x0coutput_shape\x18\x03 \x01(\t\x12\x12\n\nnum_params\x18\x04 \x01(\t\x12\x14\n\x0c\x63onnected_to\x18\x05 \x01(\t\"#\n\x07Summary\x12\x18\n\x03row\x18\x01 \x03(\x0b\x32\x0b.SummaryRow\"v\n\x0fModelGraphImage\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x1a\n\x12graph_was_rendered\x18\x02 \x01(\x08\x12\x1c\n\x14graph_import_failure\x18\x03 \x01(\x08\x12\x1b\n\x13graph_failure_error\x18\x04 \x01(\tb\x06proto3'
    ),
    dependencies=[
        masterful_dot_proto_dot_params__pb2.DESCRIPTOR,
    ])

_MODEL = _descriptor.Descriptor(
    name='Model',
    full_name='Model',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(name='name',
                                    full_name='Model.name',
                                    index=0,
                                    number=1,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='architecture_params',
                                    full_name='Model.architecture_params',
                                    index=1,
                                    number=2,
                                    type=11,
                                    cpp_type=10,
                                    label=1,
                                    has_default_value=False,
                                    default_value=None,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='summary',
                                    full_name='Model.summary',
                                    index=2,
                                    number=3,
                                    type=11,
                                    cpp_type=10,
                                    label=1,
                                    has_default_value=False,
                                    default_value=None,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='graph_image',
                                    full_name='Model.graph_image',
                                    index=3,
                                    number=4,
                                    type=11,
                                    cpp_type=10,
                                    label=1,
                                    has_default_value=False,
                                    default_value=None,
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=62,
    serialized_end=199,
)

_SUMMARYROW = _descriptor.Descriptor(
    name='SummaryRow',
    full_name='SummaryRow',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(name='layer',
                                    full_name='SummaryRow.layer',
                                    index=0,
                                    number=1,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='type',
                                    full_name='SummaryRow.type',
                                    index=1,
                                    number=2,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='output_shape',
                                    full_name='SummaryRow.output_shape',
                                    index=2,
                                    number=3,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='num_params',
                                    full_name='SummaryRow.num_params',
                                    index=3,
                                    number=4,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(name='connected_to',
                                    full_name='SummaryRow.connected_to',
                                    index=4,
                                    number=5,
                                    type=9,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b("").decode('utf-8'),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=201,
    serialized_end=306,
)

_SUMMARY = _descriptor.Descriptor(
    name='Summary',
    full_name='Summary',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(name='row',
                                    full_name='Summary.row',
                                    index=0,
                                    number=1,
                                    type=11,
                                    cpp_type=10,
                                    label=3,
                                    has_default_value=False,
                                    default_value=[],
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=308,
    serialized_end=343,
)

_MODELGRAPHIMAGE = _descriptor.Descriptor(
    name='ModelGraphImage',
    full_name='ModelGraphImage',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(name='data',
                                    full_name='ModelGraphImage.data',
                                    index=0,
                                    number=1,
                                    type=12,
                                    cpp_type=9,
                                    label=1,
                                    has_default_value=False,
                                    default_value=_b(""),
                                    message_type=None,
                                    enum_type=None,
                                    containing_type=None,
                                    is_extension=False,
                                    extension_scope=None,
                                    serialized_options=None,
                                    file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='graph_was_rendered',
            full_name='ModelGraphImage.graph_was_rendered',
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='graph_import_failure',
            full_name='ModelGraphImage.graph_import_failure',
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='graph_failure_error',
            full_name='ModelGraphImage.graph_failure_error',
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=345,
    serialized_end=463,
)

_MODEL.fields_by_name[
    'architecture_params'].message_type = masterful_dot_proto_dot_params__pb2._ARCHITECTUREPARAMS
_MODEL.fields_by_name['summary'].message_type = _SUMMARY
_MODEL.fields_by_name['graph_image'].message_type = _MODELGRAPHIMAGE
_SUMMARY.fields_by_name['row'].message_type = _SUMMARYROW
DESCRIPTOR.message_types_by_name['Model'] = _MODEL
DESCRIPTOR.message_types_by_name['SummaryRow'] = _SUMMARYROW
DESCRIPTOR.message_types_by_name['Summary'] = _SUMMARY
DESCRIPTOR.message_types_by_name['ModelGraphImage'] = _MODELGRAPHIMAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Model = _reflection.GeneratedProtocolMessageType(
    'Model',
    (_message.Message,),
    {
        'DESCRIPTOR': _MODEL,
        '__module__': 'masterful.proto.model_pb2'
        # @@protoc_insertion_point(class_scope:Model)
    })
_sym_db.RegisterMessage(Model)

SummaryRow = _reflection.GeneratedProtocolMessageType(
    'SummaryRow',
    (_message.Message,),
    {
        'DESCRIPTOR': _SUMMARYROW,
        '__module__': 'masterful.proto.model_pb2'
        # @@protoc_insertion_point(class_scope:SummaryRow)
    })
_sym_db.RegisterMessage(SummaryRow)

Summary = _reflection.GeneratedProtocolMessageType(
    'Summary',
    (_message.Message,),
    {
        'DESCRIPTOR': _SUMMARY,
        '__module__': 'masterful.proto.model_pb2'
        # @@protoc_insertion_point(class_scope:Summary)
    })
_sym_db.RegisterMessage(Summary)

ModelGraphImage = _reflection.GeneratedProtocolMessageType(
    'ModelGraphImage',
    (_message.Message,),
    {
        'DESCRIPTOR': _MODELGRAPHIMAGE,
        '__module__': 'masterful.proto.model_pb2'
        # @@protoc_insertion_point(class_scope:ModelGraphImage)
    })
_sym_db.RegisterMessage(ModelGraphImage)

# @@protoc_insertion_point(module_scope)
