# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: masterful/proto/action.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='masterful/proto/action.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1cmasterful/proto/action.proto*\xe1\x03\n\nActionName\x12\x17\n\x13\x41\x43TION_NAME_UNKNOWN\x10\x00\x12\r\n\tROTATE_90\x10\x01\x12\n\n\x06ROTATE\x10\x02\x12\x0f\n\x0bRAISE_COLOR\x10\x03\x12\x0f\n\x0bLOWER_COLOR\x10\x04\x12\x12\n\x0eRAISE_CONTRAST\x10\x05\x12\x12\n\x0eLOWER_CONTRAST\x10\x06\x12\x14\n\x10RAISE_BRIGHTNESS\x10\x07\x12\x14\n\x10LOWER_BRIGHTNESS\x10\x08\x12\x13\n\x0fRAISE_SHARPNESS\x10\t\x12\x13\n\x0fLOWER_SHARPNESS\x10\n\x12\x11\n\rAUTO_CONTRAST\x10\x0b\x12\x0c\n\x08SOLARIZE\x10\x0c\x12\r\n\tPOSTERIZE\x10\r\x12\x0c\n\x08\x45QUALIZE\x10\x0e\x12\x12\n\x0eVERTICAL_SHEAR\x10\x0f\x12\x14\n\x10HORIZONTAL_SHEAR\x10\x10\x12\x18\n\x14HORIZONTAL_TRANSLATE\x10\x11\x12\x16\n\x12VERTICAL_TRANSLATE\x10\x12\x12\n\n\x06\x43UTMIX\x10\x13\x12\t\n\x05MIXUP\x10\x14\x12\x07\n\x03LSR\x10\x15\x12\x15\n\x11HORIZONTAL_MIRROR\x10\x16\x12\x0e\n\nJITTER_HUE\x10\x17\x12\x0e\n\nRAISE_ZOOM\x10\x18\x12\x0e\n\nLOWER_ZOOM\x10\x19\x62\x06proto3')
)

_ACTIONNAME = _descriptor.EnumDescriptor(
  name='ActionName',
  full_name='ActionName',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTION_NAME_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROTATE_90', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROTATE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAISE_COLOR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOWER_COLOR', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAISE_CONTRAST', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOWER_CONTRAST', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAISE_BRIGHTNESS', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOWER_BRIGHTNESS', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAISE_SHARPNESS', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOWER_SHARPNESS', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTO_CONTRAST', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOLARIZE', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POSTERIZE', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EQUALIZE', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERTICAL_SHEAR', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HORIZONTAL_SHEAR', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HORIZONTAL_TRANSLATE', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERTICAL_TRANSLATE', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUTMIX', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MIXUP', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LSR', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HORIZONTAL_MIRROR', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JITTER_HUE', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAISE_ZOOM', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOWER_ZOOM', index=25, number=25,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=33,
  serialized_end=514,
)
_sym_db.RegisterEnumDescriptor(_ACTIONNAME)

ActionName = enum_type_wrapper.EnumTypeWrapper(_ACTIONNAME)
ACTION_NAME_UNKNOWN = 0
ROTATE_90 = 1
ROTATE = 2
RAISE_COLOR = 3
LOWER_COLOR = 4
RAISE_CONTRAST = 5
LOWER_CONTRAST = 6
RAISE_BRIGHTNESS = 7
LOWER_BRIGHTNESS = 8
RAISE_SHARPNESS = 9
LOWER_SHARPNESS = 10
AUTO_CONTRAST = 11
SOLARIZE = 12
POSTERIZE = 13
EQUALIZE = 14
VERTICAL_SHEAR = 15
HORIZONTAL_SHEAR = 16
HORIZONTAL_TRANSLATE = 17
VERTICAL_TRANSLATE = 18
CUTMIX = 19
MIXUP = 20
LSR = 21
HORIZONTAL_MIRROR = 22
JITTER_HUE = 23
RAISE_ZOOM = 24
LOWER_ZOOM = 25


DESCRIPTOR.enum_types_by_name['ActionName'] = _ACTIONNAME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


# @@protoc_insertion_point(module_scope)
