# Generated by Django 3.2.8 on 2022-10-19 12:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0013_trainingrun_datasets'),
    ]

    operations = [
        migrations.AddField(
            model_name='trainingrun',
            name='with_cli',
            field=models.BooleanField(default=False),
        ),
    ]
